package cn.gbase8.gswt;

import java.io.File;
import java.text.Collator;
import java.util.Comparator;
import java.util.LinkedList;
import java.util.List;
import java.util.Locale;

import util.Common;

public class UniqID {
	private static final Collator collator = Collator.getInstance(Locale.CHINA);
	private String uniqID;
	private GBaseConnectionParamater gcp;

	public GBaseConnectionParamater getGcp() {
		return gcp;
	}

	public void setGcp(GBaseConnectionParamater gcp) {
		this.gcp = gcp;
	}

	public String getUniqID() {
		return uniqID;
	}

	private File fileUniqID;
	private File fileGBaseConnectionParamater;
	private File fileFunction;
	private File filePassword;

	public UniqID(String uniqID, String password) {
		this.uniqID = uniqID;
		fileUniqID = new File(PATH + "/" + uniqID);
		fileGBaseConnectionParamater = new File(PATH + "/" + uniqID + "/gcps");
		fileFunction = new File(PATH + "/" + uniqID + "/functions");
		filePassword = new File(PATH + "/" + uniqID + "/" + Common.md5utf8(password));
	}

	// 配置文件的保存路径，目前是放在/WEB-INF/userUniqIDS下。
	private static final String PATH = UniqID.class.getClassLoader().getResource("/").getPath() + "/../userUniqIDs/";

	public boolean exists() {
		return fileUniqID.exists();
	}

	public boolean login() {
		return fileUniqID.exists() && filePassword.exists();
	}

	public boolean create() {
		try {
			return fileGBaseConnectionParamater.mkdirs() && fileFunction.mkdirs() && filePassword.createNewFile();
		} catch (Exception ex) {
			ex.printStackTrace();
			return false;
		}
	}

	public List<GBaseConnectionParamater> getGBaseConnectionParamaters() {
		String[] gcpFiles = fileGBaseConnectionParamater.list();
		List<GBaseConnectionParamater> rtn = new LinkedList<GBaseConnectionParamater>();
		for (String gcpFile : gcpFiles) {
			GBaseConnectionParamater gcp = new GBaseConnectionParamater();
			gcp.loadFromFile(new File(fileGBaseConnectionParamater.getPath() + "/" + gcpFile));
			rtn.add(gcp);
		}
		return rtn;
	}

	public GBaseConnectionParamater getGBaseConnectionParamater(String filename) {
		GBaseConnectionParamater gcp = new GBaseConnectionParamater();
		gcp.loadFromFile(new File(fileGBaseConnectionParamater.getPath() + "/" + filename));
		return gcp;

	}

	/**
	 * 保存连接 文件名为注释的md5加上时间戳
	 * 
	 * @param gcp
	 * @return
	 */
	public boolean saveGBaseConnectionParamater(GBaseConnectionParamater gcp) {
		if (Common.isBlank(gcp.filename)) {
			gcp.filename = Common.md5utf8(gcp.comment) + "_" + System.currentTimeMillis();
		}
		return gcp.saveToFile(new File(fileGBaseConnectionParamater.getPath() + "/" + gcp.filename));
	}

	/**
	 * 删除连接
	 * 
	 * @param filename
	 * @return
	 */
	public boolean removeGBaseConnectionParamater(String filename) {
		return new File(fileGBaseConnectionParamater.getPath() + "/" + filename).delete();
	}

	public List<Function> getFunctions() {
		String[] funcFiles = fileFunction.list();
		List<Function> rtn = new LinkedList<Function>();
		for (String funcFile : funcFiles) {
			Function func = new Function();
			func.loadFromFile(new File(fileFunction.getPath() + "/" + funcFile));
			rtn.add(func);
		}

		rtn.sort(new Comparator<Function>() {

			@Override
			public int compare(Function o1, Function o2) {
				int c1 = o1.up.compareTo(o2.up);
				if (c1 == 0) {
					return collator.getCollationKey(o1.comment).compareTo(collator.getCollationKey(o2.comment));
				} else {
					return c1 * -1;
				}
			}
		});
		return rtn;
	}

	public Function getFunction(String filename) {
		Function func = new Function();
		func.loadFromFile(new File(fileFunction.getPath() + "/" + filename));
		return func;
	}

	/**
	 * 保存SQL 文件名为名字的md5加上时间戳
	 * 
	 * @param func SQL功能
	 * @return
	 */
	public boolean saveFunction(Function func) {
		if (Common.isBlank(func.filename)) {
			func.filename = Common.md5utf8(func.comment) + "_" + System.currentTimeMillis();
		}
		return func.saveToFile(new File(fileFunction.getPath() + "/" + func.filename));
	}

	public boolean removeFunction(String filename) {
		return new File(fileFunction.getPath() + "/" + filename).delete();
	}
}
